@@ -19,7 +19,10 @@ def _get_qoption_value(model, key, fail_silently):
     if not value:
         try:
             opt = model.objects.get(key=key)
-            value = opt.value
+            if hasattr(opt, 'title'):
+                value = [opt.title, opt.text]
+            else:
+                value = opt.value
         except model.DoesNotExist:
             if fail_silently:
                 value = ''
@@ -27,7 +30,11 @@ def _get_qoption_value(model, key, fail_silently):
                 raise model.DoesNotExist('No record with key "{0}"'.format(key))
         except model.MultipleObjectsReturned:
             if fail_silently:
-                value = model.objects.filter(key=key)[0]
+                opt = model.objects.filter(key=key)[0]
+                if hasattr(opt, 'title'):
+                    value = [opt.title, opt.text]
+                else:
+                    value = opt.value
             else:
                 raise model.DoesNotExist('Returned more than one record with key "{0}"'.format(key))
 
